==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/ConnectorDefinitionsPermissionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.ConnectorDefinitionsPermissionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The required Permissions for the connector.
 * @property customs Gets or sets the customs permissions required for the user to create connections.
 * @property licenses Gets or sets the required licenses for the user to create connections.
 * @property resourceProvider Gets or sets the resource provider permissions required for the user to create connections.
 * @property tenant Gets or sets the required tenant permissions for the connector.
 */
public data class ConnectorDefinitionsPermissionsArgs(
    public val customs: Output<List<CustomPermissionDetailsArgs>>? = null,
    public val licenses: Output<List<String>>? = null,
    public val resourceProvider: Output<List<ConnectorDefinitionsResourceProviderArgs>>? = null,
    public val tenant: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.ConnectorDefinitionsPermissionsArgs> {
    override fun toJava():
        com.pulumi.azurenative.securityinsights.inputs.ConnectorDefinitionsPermissionsArgs =
        com.pulumi.azurenative.securityinsights.inputs.ConnectorDefinitionsPermissionsArgs.builder()
            .customs(
                customs?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .licenses(licenses?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .resourceProvider(
                resourceProvider?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tenant(tenant?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ConnectorDefinitionsPermissionsArgs].
 */
@PulumiTagMarker
public class ConnectorDefinitionsPermissionsArgsBuilder internal constructor() {
    private var customs: Output<List<CustomPermissionDetailsArgs>>? = null

    private var licenses: Output<List<String>>? = null

    private var resourceProvider: Output<List<ConnectorDefinitionsResourceProviderArgs>>? = null

    private var tenant: Output<List<String>>? = null

    /**
     * @param value Gets or sets the customs permissions required for the user to create connections.
     */
    @JvmName("gaxsdrqlrlmedkww")
    public suspend fun customs(`value`: Output<List<CustomPermissionDetailsArgs>>) {
        this.customs = value
    }

    @JvmName("tbobpgeysngiajyp")
    public suspend fun customs(vararg values: Output<CustomPermissionDetailsArgs>) {
        this.customs = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the customs permissions required for the user to create connections.
     */
    @JvmName("njrtnwosaalaqlnx")
    public suspend fun customs(values: List<Output<CustomPermissionDetailsArgs>>) {
        this.customs = Output.all(values)
    }

    /**
     * @param value Gets or sets the required licenses for the user to create connections.
     */
    @JvmName("hwvcvqotdwhcoglw")
    public suspend fun licenses(`value`: Output<List<String>>) {
        this.licenses = value
    }

    @JvmName("jawlcfqlboyqqyne")
    public suspend fun licenses(vararg values: Output<String>) {
        this.licenses = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the required licenses for the user to create connections.
     */
    @JvmName("dqtyiowishvavarn")
    public suspend fun licenses(values: List<Output<String>>) {
        this.licenses = Output.all(values)
    }

    /**
     * @param value Gets or sets the resource provider permissions required for the user to create connections.
     */
    @JvmName("aonpclwhxjnxfjko")
    public suspend
    fun resourceProvider(`value`: Output<List<ConnectorDefinitionsResourceProviderArgs>>) {
        this.resourceProvider = value
    }

    @JvmName("dbmehjwebrdudpqf")
    public suspend fun resourceProvider(
        vararg
        values: Output<ConnectorDefinitionsResourceProviderArgs>,
    ) {
        this.resourceProvider = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the resource provider permissions required for the user to create connections.
     */
    @JvmName("ktrlqlcroejfgbgb")
    public suspend
    fun resourceProvider(values: List<Output<ConnectorDefinitionsResourceProviderArgs>>) {
        this.resourceProvider = Output.all(values)
    }

    /**
     * @param value Gets or sets the required tenant permissions for the connector.
     */
    @JvmName("ijfffsgsjxvnhcbn")
    public suspend fun tenant(`value`: Output<List<String>>) {
        this.tenant = value
    }

    @JvmName("fhqpwrurhjfrtbie")
    public suspend fun tenant(vararg values: Output<String>) {
        this.tenant = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the required tenant permissions for the connector.
     */
    @JvmName("hxvdrvanoiemiunb")
    public suspend fun tenant(values: List<Output<String>>) {
        this.tenant = Output.all(values)
    }

    /**
     * @param value Gets or sets the customs permissions required for the user to create connections.
     */
    @JvmName("eqowlvjfhdvyrrbj")
    public suspend fun customs(`value`: List<CustomPermissionDetailsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customs = mapped
    }

    /**
     * @param argument Gets or sets the customs permissions required for the user to create connections.
     */
    @JvmName("kcuknloawtaighsn")
    public suspend
    fun customs(argument: List<suspend CustomPermissionDetailsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            CustomPermissionDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.customs = mapped
    }

    /**
     * @param argument Gets or sets the customs permissions required for the user to create connections.
     */
    @JvmName("heeqwbbcglsafkfw")
    public suspend fun customs(
        vararg
        argument: suspend CustomPermissionDetailsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            CustomPermissionDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.customs = mapped
    }

    /**
     * @param argument Gets or sets the customs permissions required for the user to create connections.
     */
    @JvmName("kjpbhbvusiuhilpb")
    public suspend fun customs(argument: suspend CustomPermissionDetailsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            CustomPermissionDetailsArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.customs = mapped
    }

    /**
     * @param values Gets or sets the customs permissions required for the user to create connections.
     */
    @JvmName("ncjumuhastiqycai")
    public suspend fun customs(vararg values: CustomPermissionDetailsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.customs = mapped
    }

    /**
     * @param value Gets or sets the required licenses for the user to create connections.
     */
    @JvmName("csfpctjnrscmfggw")
    public suspend fun licenses(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.licenses = mapped
    }

    /**
     * @param values Gets or sets the required licenses for the user to create connections.
     */
    @JvmName("dgosddyroaeoqguf")
    public suspend fun licenses(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.licenses = mapped
    }

    /**
     * @param value Gets or sets the resource provider permissions required for the user to create connections.
     */
    @JvmName("pvwsnmanweckbfib")
    public suspend fun resourceProvider(`value`: List<ConnectorDefinitionsResourceProviderArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceProvider = mapped
    }

    /**
     * @param argument Gets or sets the resource provider permissions required for the user to create connections.
     */
    @JvmName("imnyedygjxbxfmbf")
    public suspend
    fun resourceProvider(argument: List<suspend ConnectorDefinitionsResourceProviderArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConnectorDefinitionsResourceProviderArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceProvider = mapped
    }

    /**
     * @param argument Gets or sets the resource provider permissions required for the user to create connections.
     */
    @JvmName("yldntytvyluhxgoj")
    public suspend fun resourceProvider(
        vararg
        argument: suspend ConnectorDefinitionsResourceProviderArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConnectorDefinitionsResourceProviderArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceProvider = mapped
    }

    /**
     * @param argument Gets or sets the resource provider permissions required for the user to create connections.
     */
    @JvmName("iecmkwkjtlbsfrei")
    public suspend
    fun resourceProvider(argument: suspend ConnectorDefinitionsResourceProviderArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ConnectorDefinitionsResourceProviderArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.resourceProvider = mapped
    }

    /**
     * @param values Gets or sets the resource provider permissions required for the user to create connections.
     */
    @JvmName("oyhcidbpvfgyqimr")
    public suspend fun resourceProvider(vararg values: ConnectorDefinitionsResourceProviderArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceProvider = mapped
    }

    /**
     * @param value Gets or sets the required tenant permissions for the connector.
     */
    @JvmName("tneatlwbbpjatydf")
    public suspend fun tenant(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenant = mapped
    }

    /**
     * @param values Gets or sets the required tenant permissions for the connector.
     */
    @JvmName("tcfkrvwlanrteirk")
    public suspend fun tenant(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tenant = mapped
    }

    internal fun build(): ConnectorDefinitionsPermissionsArgs = ConnectorDefinitionsPermissionsArgs(
        customs = customs,
        licenses = licenses,
        resourceProvider = resourceProvider,
        tenant = tenant,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/ConnectorDefinitionsPermissionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.ConnectorDefinitionsPermissionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The required Permissions for the connector.
 * @property customs Gets or sets the customs permissions required for the user to create connections.
 * @property licenses Gets or sets the required licenses for the user to create connections.
 * @property resourceProvider Gets or sets the resource provider permissions required for the user to create connections.
 * @property tenant Gets or sets the required tenant permissions for the connector.
 */
public data class ConnectorDefinitionsPermissionsArgs(
    public val customs: Output<List<CustomPermissionDetailsArgs>>? = null,
    public val licenses: Output<List<String>>? = null,
    public val resourceProvider: Output<List<ConnectorDefinitionsResourceProviderArgs>>? = null,
    public val tenant: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.ConnectorDefinitionsPermissionsArgs> {
    override fun toJava():
        com.pulumi.azurenative.securityinsights.inputs.ConnectorDefinitionsPermissionsArgs =
        com.pulumi.azurenative.securityinsights.inputs.ConnectorDefinitionsPermissionsArgs.builder()
            .customs(
                customs?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .licenses(licenses?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .resourceProvider(
                resourceProvider?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tenant(tenant?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ConnectorDefinitionsPermissionsArgs].
 */
@PulumiTagMarker
public class ConnectorDefinitionsPermissionsArgsBuilder internal constructor() {
    private var customs: Output<List<CustomPermissionDetailsArgs>>? = null

    private var licenses: Output<List<String>>? = null

    private var resourceProvider: Output<List<ConnectorDefinitionsResourceProviderArgs>>? = null

    private var tenant: Output<List<String>>? = null

    /**
     * @param value Gets or sets the customs permissions required for the user to create connections.
     */
    @JvmName("rsflweoruoqrpuge")
    public suspend fun customs(`value`: Output<List<CustomPermissionDetailsArgs>>) {
        this.customs = value
    }

    @JvmName("okggafedienvgrvl")
    public suspend fun customs(vararg values: Output<CustomPermissionDetailsArgs>) {
        this.customs = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the customs permissions required for the user to create connections.
     */
    @JvmName("ejriikgxjkoipluo")
    public suspend fun customs(values: List<Output<CustomPermissionDetailsArgs>>) {
        this.customs = Output.all(values)
    }

    /**
     * @param value Gets or sets the required licenses for the user to create connections.
     */
    @JvmName("gnwuresclswuodae")
    public suspend fun licenses(`value`: Output<List<String>>) {
        this.licenses = value
    }

    @JvmName("yjumvxtssnlbtblm")
    public suspend fun licenses(vararg values: Output<String>) {
        this.licenses = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the required licenses for the user to create connections.
     */
    @JvmName("fwionpymxufjkxlh")
    public suspend fun licenses(values: List<Output<String>>) {
        this.licenses = Output.all(values)
    }

    /**
     * @param value Gets or sets the resource provider permissions required for the user to create connections.
     */
    @JvmName("vswiwarffxaxjhor")
    public suspend
    fun resourceProvider(`value`: Output<List<ConnectorDefinitionsResourceProviderArgs>>) {
        this.resourceProvider = value
    }

    @JvmName("conedxyjfvlulfom")
    public suspend fun resourceProvider(
        vararg
        values: Output<ConnectorDefinitionsResourceProviderArgs>,
    ) {
        this.resourceProvider = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the resource provider permissions required for the user to create connections.
     */
    @JvmName("hlokyacnkwdoadeq")
    public suspend
    fun resourceProvider(values: List<Output<ConnectorDefinitionsResourceProviderArgs>>) {
        this.resourceProvider = Output.all(values)
    }

    /**
     * @param value Gets or sets the required tenant permissions for the connector.
     */
    @JvmName("eaucmoesuvqbiule")
    public suspend fun tenant(`value`: Output<List<String>>) {
        this.tenant = value
    }

    @JvmName("urkpntyhworxaaot")
    public suspend fun tenant(vararg values: Output<String>) {
        this.tenant = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the required tenant permissions for the connector.
     */
    @JvmName("jkqycylwkwvbjvdd")
    public suspend fun tenant(values: List<Output<String>>) {
        this.tenant = Output.all(values)
    }

    /**
     * @param value Gets or sets the customs permissions required for the user to create connections.
     */
    @JvmName("vjcuhqsiehefpudx")
    public suspend fun customs(`value`: List<CustomPermissionDetailsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customs = mapped
    }

    /**
     * @param argument Gets or sets the customs permissions required for the user to create connections.
     */
    @JvmName("jdpinstocwcvmngs")
    public suspend
    fun customs(argument: List<suspend CustomPermissionDetailsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            CustomPermissionDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.customs = mapped
    }

    /**
     * @param argument Gets or sets the customs permissions required for the user to create connections.
     */
    @JvmName("atgdahytdcoytoyf")
    public suspend fun customs(
        vararg
        argument: suspend CustomPermissionDetailsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            CustomPermissionDetailsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.customs = mapped
    }

    /**
     * @param argument Gets or sets the customs permissions required for the user to create connections.
     */
    @JvmName("kbkhulgwncgwuunv")
    public suspend fun customs(argument: suspend CustomPermissionDetailsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            CustomPermissionDetailsArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.customs = mapped
    }

    /**
     * @param values Gets or sets the customs permissions required for the user to create connections.
     */
    @JvmName("snntdmlqmhafwhuw")
    public suspend fun customs(vararg values: CustomPermissionDetailsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.customs = mapped
    }

    /**
     * @param value Gets or sets the required licenses for the user to create connections.
     */
    @JvmName("tqhcolnmxowukwge")
    public suspend fun licenses(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.licenses = mapped
    }

    /**
     * @param values Gets or sets the required licenses for the user to create connections.
     */
    @JvmName("caxnoextvbfnnjqf")
    public suspend fun licenses(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.licenses = mapped
    }

    /**
     * @param value Gets or sets the resource provider permissions required for the user to create connections.
     */
    @JvmName("lytneeugtokwkiid")
    public suspend fun resourceProvider(`value`: List<ConnectorDefinitionsResourceProviderArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceProvider = mapped
    }

    /**
     * @param argument Gets or sets the resource provider permissions required for the user to create connections.
     */
    @JvmName("abcjqnagrogdearu")
    public suspend
    fun resourceProvider(argument: List<suspend ConnectorDefinitionsResourceProviderArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConnectorDefinitionsResourceProviderArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceProvider = mapped
    }

    /**
     * @param argument Gets or sets the resource provider permissions required for the user to create connections.
     */
    @JvmName("fxobafvgrfsbtypk")
    public suspend fun resourceProvider(
        vararg
        argument: suspend ConnectorDefinitionsResourceProviderArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConnectorDefinitionsResourceProviderArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceProvider = mapped
    }

    /**
     * @param argument Gets or sets the resource provider permissions required for the user to create connections.
     */
    @JvmName("dyskgdcnwmxsbdhi")
    public suspend
    fun resourceProvider(argument: suspend ConnectorDefinitionsResourceProviderArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ConnectorDefinitionsResourceProviderArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.resourceProvider = mapped
    }

    /**
     * @param values Gets or sets the resource provider permissions required for the user to create connections.
     */
    @JvmName("wdtdjlpvoyurdbik")
    public suspend fun resourceProvider(vararg values: ConnectorDefinitionsResourceProviderArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceProvider = mapped
    }

    /**
     * @param value Gets or sets the required tenant permissions for the connector.
     */
    @JvmName("euufbedybwhpoflw")
    public suspend fun tenant(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenant = mapped
    }

    /**
     * @param values Gets or sets the required tenant permissions for the connector.
     */
    @JvmName("iiimhdsxgcochicg")
    public suspend fun tenant(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tenant = mapped
    }

    internal fun build(): ConnectorDefinitionsPermissionsArgs = ConnectorDefinitionsPermissionsArgs(
        customs = customs,
        licenses = licenses,
        resourceProvider = resourceProvider,
        tenant = tenant,
    )
}
